# k3handy

[![Action-CI](https://github.com/pykit3/k3handy/actions/workflows/python-package.yml/badge.svg)](https://github.com/pykit3/k3handy/actions/workflows/python-package.yml)
[![Build Status](https://travis-ci.com/pykit3/k3handy.svg?branch=master)](https://travis-ci.com/pykit3/k3handy)
[![Documentation Status](https://readthedocs.org/projects/k3handy/badge/?version=stable)](https://k3handy.readthedocs.io/en/stable/?badge=stable)
[![Package](https://img.shields.io/pypi/pyversions/k3handy)](https://pypi.org/project/k3handy)

handy alias of mostly used functions

k3handy is a component of [pykit3] project: a python3 toolkit set.


k3handy is collection of mostly used  utilities.



# Install

```
pip install k3handy
```

# Synopsis

```python

```

#   Author

Zhang Yanpo (张炎泼) <drdr.xp@gmail.com>

#   Copyright and License

The MIT License (MIT)

Copyright (c) 2015 Zhang Yanpo (张炎泼) <drdr.xp@gmail.com>


[pykit3]: https://github.com/pykit3